@@ -1,10 +1,8 @@
 #pragma once
 
-#include <stdint.h>
 #include <stdbool.h>
-#include <netinet/in.h>
-#include "net.h"
 #include "misc.h"
+#include "net.h"
 
 /* socket idx/mark */
 #define CHINADNS1_IDX 0
@@ -20,7 +18,7 @@
 
 #define is_chinadns_idx(idx) ((idx) == CHINADNS1_IDX || (idx) == CHINADNS2_IDX)
 
-/* no-ipv6 bit flag */
+/* no-ipv6 bit flag (u8) */
 #define NOAAAA_ALL         (-1) /* max value of unsigned integer of any width, all bits are 1 */
 #define NOAAAA_TAG_GFW     (1U)
 #define NOAAAA_TAG_CHN     (1U << 1)
@@ -28,41 +26,37 @@
 #define NOAAAA_CHINA_DNS   (1U << 3)
 #define NOAAAA_TRUST_DNS   (1U << 4)
 #define NOAAAA_CHINA_IPCHK (1U << 5)
+#define NOAAAA_TRUST_IPCHK (1U << 6)
 
 #define is_filter_all_v6(flags) ((flags) == (__typeof__(flags))NOAAAA_ALL)
 
-/* setname max len (include \0) */
-#define IPSET_MAXNAMELEN 32
-
-/* port string max len (include \0) | "65535" */
-#define PORTSTR_MAXLEN 6
-
-/* addr+port string max len (include \0) | "addr#port" */
-#define ADDRPORT_STRLEN (INET6_ADDRSTRLEN + PORTSTR_MAXLEN)
+/* g_repeat_times, too large may cause stack overflow */
+#define MAX_REPEAT_TIMES 5
 
 /* is enable verbose logging */
-#define IF_VERBOSE unlikely_if (g_verbose)
+#define if_verbose unlikely_if (g_verbose)
 
 extern bool        g_verbose;
 extern bool        g_reuse_port;
 extern bool        g_noip_as_chnip;
-extern uint8_t     g_noaaaa_query;
-extern uint8_t     g_default_tag;
+extern u8          g_noaaaa_query;
+extern u8          g_default_tag;
 
 extern const char *g_gfwlist_fname;
 extern const char *g_chnlist_fname;
 extern bool        g_gfwlist_first;
+extern bool        g_add_tagchn_ip;
 
-extern char        g_ipset_setname4[IPSET_MAXNAMELEN];
-extern char        g_ipset_setname6[IPSET_MAXNAMELEN];
+extern const char *g_ipset_name4;
+extern const char *g_ipset_name6;
 
-extern char        g_bind_ipstr[INET6_ADDRSTRLEN];
-extern portno_t    g_bind_portno;
-extern skaddr_u    g_bind_skaddr;
+extern const char  *g_bind_ip;
+extern u16          g_bind_port;
+extern union skaddr g_bind_skaddr;
 
-extern char        g_remote_ipports[SERVER_MAXCNT][ADDRPORT_STRLEN];
-extern skaddr_u    g_remote_skaddrs[SERVER_MAXCNT];
-extern int         g_upstream_timeout_sec;
-extern uint8_t     g_repeat_times;
+extern const char   *g_upstream_addrs[SERVER_MAXCNT];
+extern union skaddr  g_upstream_skaddrs[SERVER_MAXCNT];
+extern int           g_upstream_timeout_sec;
+extern u8            g_repeat_times;
 
 void opt_parse(int argc, char *argv[]);
